        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 19 <strong>control</strong><br>0,2,4,6,7,11,13,16,20,22,26,31,36,37,38,42,43,45,50';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 18 <br>3,5,8,10,14,15,18,21,23,24,25,32,33,40,41,47,48,49';}
       if(rr==1 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>1,9,12,17,19,27,28,29,30,34,35,39,44,46';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 19 <strong>control</strong><br>0,2,4,6,7,11,13,16,20,22,26,31,36,37,38,42,43,45,50';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 18 <br>3,5,8,10,14,15,18,21,23,24,25,32,33,40,41,47,48,49';}
       if(rr==8 && cc==3){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>1,9,12,17,19,27,28,29,30,34,35,39,44,46';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 19 <strong>control</strong><br>0,2,4,6,7,11,13,16,20,22,26,31,36,37,38,42,43,45,50';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 18 <br>3,5,8,10,14,15,18,21,23,24,25,32,33,40,41,47,48,49';}
       if(rr==18 && cc==3){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>1,9,12,17,19,27,28,29,30,34,35,39,44,46';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 19 <strong>control</strong><br>0,2,4,6,7,11,13,16,20,22,26,31,36,37,38,42,43,45,50';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 18 <br>3,5,8,10,14,15,18,21,23,24,25,32,33,40,41,47,48,49';}
       if(rr==24 && cc==3){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>1,9,12,17,19,27,28,29,30,34,35,39,44,46';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 19 <strong>control</strong><br>0,2,4,6,7,11,13,16,20,22,26,31,36,37,38,42,43,45,50';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 18 <br>3,5,8,10,14,15,18,21,23,24,25,32,33,40,41,47,48,49';}
       if(rr==44 && cc==3){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>1,9,12,17,19,27,28,29,30,34,35,39,44,46';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>1</strong> representante: <strong>45</strong> miembros: 19 <strong>control</strong><br>0,2,4,6,7,11,13,16,20,22,26,31,36,37,38,42,43,45,50';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>2</strong> representante: <strong>40</strong> miembros: 18 <br>3,5,8,10,14,15,18,21,23,24,25,32,33,40,41,47,48,49';}
       if(rr==45 && cc==3){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260620 a 12</strong> UTC HH+096 (rango:084-108)<br>grupo: <strong>3</strong> representante: <strong>44</strong> miembros: 14 <br>1,9,12,17,19,27,28,29,30,34,35,39,44,46';}
}
